#
# spec file for package python-ironicclient
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname python-ironicclient
Name:           python-ironicclient
Version:        1.11.1
Release:        1.9
Summary:        Python API and CLI for OpenStack Ironic
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://launchpad.net/%{sname}
Source0:        https://pypi.io/packages/source/p/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-Babel >= 2.3.4
BuildRequires:  python-PrettyTable >= 0.7.1
BuildRequires:  python-PyYAML >= 3.10.0
BuildRequires:  python-appdirs >= 1.3.0
BuildRequires:  python-devel
BuildRequires:  python-dogpile.cache >= 0.6.2
BuildRequires:  python-fixtures >= 3.0.0
BuildRequires:  python-jsonschema >= 2.0.0
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-openstackclient >= 3.3.0
BuildRequires:  python-os-testr >= 0.8.0
BuildRequires:  python-osc-lib >= 1.2.0
BuildRequires:  python-oslo.i18n >= 2.1.0
BuildRequires:  python-oslo.utils >= 3.18.0
BuildRequires:  python-oslotest >= 1.10.0
BuildRequires:  python-pbr >= 1.8
BuildRequires:  python-python-subunit >= 0.0.18
BuildRequires:  python-requests >= 2.10.0
BuildRequires:  python-requests-mock >= 1.1
BuildRequires:  python-testtools >= 1.4.0
Requires:       python-PrettyTable >= 0.7.1
Requires:       python-PyYAML >= 3.10.0
Requires:       python-appdirs >= 1.3.0
Requires:       python-dogpile.cache >= 0.6.2
Requires:       python-jsonschema >= 2.0.0
Requires:       python-keystoneauth1 >= 2.18.0
Requires:       python-openstackclient >= 3.3.0
Requires:       python-osc-lib >= 1.2.0
Requires:       python-oslo.i18n >= 2.1.0
Requires:       python-oslo.utils >= 3.18.0
Requires:       python-pbr >= 1.8
Requires:       python-requests >= 2.10.0
Requires:       python-six >= 1.9.0
BuildArch:      noarch

%description
OpenStack Bare Metal Provisioning API Client Library

This is a client for the OpenStack Ironic API. It provides a Python API (the
ironicclient module) and a command-line interface (ironic).

%package doc
Summary:        Documentation for OpenStack Ironic API Client
Group:          Documentation
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 4.7.0
BuildRequires:  python-reno >= 1.8.0

%description doc
This is a client for the OpenStack Ironic API (Bare Metal. There's a
Python API (the ironicclient module), and a command-line script (ironic).
Each implements 100% of the OpenStack Ironic API.
This package contains auto-generated documentation.

%prep
%autosetup -n %{sname}-%{version}
%py_req_cleanup

%build
%{py2_build}

%{__python2} setup.py build_sphinx
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py2_install}
# bash completion
install -p -D -m 644 tools/ironic.bash_completion %{buildroot}%{_sysconfdir}/bash_completion.d/ironic.bash_completion

%check
%{__python2} setup.py testr

%files
%license LICENSE
%doc README.rst
%{_bindir}/ironic
%{python2_sitelib}/ironicclient
%{python2_sitelib}/*.egg-info
%{_bindir}/ironic
%{_sysconfdir}/bash_completion.d/ironic.bash_completion

%files doc
%license LICENSE
%doc doc/build/html

%changelog
* Mon Mar 27 2017 cloud-devel@suse.de
- update to version 1.11.1:
  - Update UPPER_CONSTRAINTS_FILE for stable/ocata
  - Bump the LAST_KNOWN_API_VERSION to 29 in OSC
  - Update .gitreview for stable/ocata
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.11.0:
  - use utils.key_value_pairs_to_dict()
  - Simplify heading capitalization.
  - Avoid string interpolation in logging calls
  - Fixed json response func tests
  - Fix import of ironicclient and reformat docstring
  - Support soft reboot and soft power off with timeout for OSC
  - Refactor provision state so all actions can use inherited take_action
  - Fix exception message creation in get_client()
  - Fix node-inject-nmi to pass an empty body
  - [trivial] Fix underline length under title in doc
  - OSC plugin support microversions 1.21 & 1.22
  - Move duplicated info to new v1/utils.py
  - List required arguments in '--help' message in Ironic Client.
  - Enable release notes translation
  - Add interface attach/detach support
  - Set OSC default baremetal api version as in ironicclient
  - Add docs for create command
  - Add a new OSC command for Inject NMI
  - Follow up nits in the patch "ironic node-inject-nmi"
  - Use identity api version 3 for OSC plugin tests
  - Use ConfigParser instead of SafeConfigParser in Python 3
  - Update reno for stable/newton
  - Add warning message for baremetal node set/unset commands
  - Hide 'nodes' field from chassis OSC subcommands output
  - Add test for ironic port-list command
  - Simplify heading capitalization in shell's HelpFormatter.
  - TrivialFix Remove white space between print and ()
  - Show team and repo badges on README
  - Raise on NodeManager get when invalid identifier provided
  - Add basic tests for OSC plugin baremetal node commands
  - Allow import more than one func from i18n
  - Replace six.iteritems() with .items()
  - Document updating nested node attributes with CLI
  - Replace yaml.load() with yaml.safe_load()
  - If no resource, don't call Resource.to_dict()
  - Support --os-baremetal-api-version latest
  - Fix multiple ports deletion
  - standardize release note page names and ordering
  - Update release note for fix to required args
  - [trivial] Fix of apostrophe in tox.ini
  - Update to hacking 0.12.0 and use new checks
  - Update tox envs list
  - Extend VIF attach commands
  - Add more tests to node_shell
  - Use oslo_serialization.base64 to follow OpenStack Python3
  - Add soft reboot/poweroff power states.
  - 'ironic create' handles file args
  - Add a new command "ironic node-inject-nmi"
  - Add --no-maintenance to OSC 'baremetal node list'
  - Don't write python bytecode while testing
  - Use function import_versioned_module from oslo.utils
  - Add --wait to OSC provisioning commands
  - Strip endpoint version in OSC plugin
  - Add tests for provision state commands
  - Describe possible exception in docstring
  - Update .gitignore to ignore .idea of PyCharm
  - Add python API and CLI for port groups
  - Fix API object representation in unittests
  - Fix python3 compatibility when HTTP Error are returned
  - Add plug-in summary for osc doc
  - Include jsonschema only once in requirements
  - Use uuidutils instead of uuid.uuid4()
  - Add prefix "$" for command examples
  - Add tests for maintenance mode commands
  - OSC add capability to remove node/chassis_uuid
  - Extend OSC "node list" cmd to fetch nodes without instance UUID
  - Adds --chassis-uuid to osc 'baremetal node set'
  - Add mode and properties to portgroup OSC plugin
  - Allow creating portgroups via create commands
  - Typo fix: prefered => preferred
  - Pass argument as params in test_port_update
  - Log warning if no property for (Un)Set commands
  - Fix display of chassis UUID field if empty
  - Hide 'ports' field from node OSC subcommands output
  - Add mode and properties to portgroup
  - Add portgroup support to osc plugin
  - Fix help message for the node-vif-attach command
  - Updated from global requirements
  - [trivial] Remove unused variables assignment
  - Change os_tenant_name to os_project_name in tests configuration script
* Sat Dec  3 2016 dmueller@suse.com
- update to 1.7.1:
  * 'ironic create' handles file args
* Sun Oct  2 2016 dmueller@suse.com
- sync descriptions with git
* Mon Sep  5 2016 tbechtold@suse.com
  update to version 1.7.0
  * Use osc-lib instead of openstackclient
  * Deprecate -l option for port creation in OSC plugin
  * Set/unset node's target RAID config via OSC command
  * Clean up release notes for 1.7
  * Add openstack baremetal driver commands
  * Add baremetal port set command to OSC plugin
  * Fail with more meaningful error while creating client
  * Update hacking test-requirement
  * Correct a couple small grammar things in release notes
  * Verify JSON response of driver commands
  * Add key_value_pairs_to_dict() method
  * Trivial: Fix doc string for class DeleteBaremetalNode
  * Fix i18n problems in shell.py
  * Remove discover from test-requirements
  * Add 'openstack baremetal node adopt' command
  * Add baremetal port list command to OSC plugin
  * Adds node boot device & passthru OSC commands
  * Using assertIsNone() is preferred over assertEqual()
  * Trivial: remove redundant parentheses
  * Add node validate OSC command
  * Use constraints for all the things
  * Add baremetal port unset command to OSC plugin
  * Fix uuid to UUID in expected error messages
  * Add --node to 'openstack baremetal port list'
  * Add --wait flag for provision actions and wait_for_provision_state function
  * Add create command to ironic client
  * Remove unused LONG_FIELDS
  * Update help shown for node-delete
  * Add internal_info field to port
  * Change 'P' to 'Queens' and add deprecation date
  * Remove unused variables assignments in OSC plugin unit tests
  * Add openstack baremetal chassis commands
  * Sync tools/tox_install.sh
  * Trivial: Remove useless spaces
  * Add docs target to tox.ini
  * Adds 'openstack baremetal node console' commands
  * Use osc_lib instead of cliff
  * Add --chassis to 'openstack baremetal node list'
  * Make shell main() specify return value in exit code
  * Updated from global requirements
  * Add baremetal port delete command to OSC plugin
* Thu Sep  1 2016 tbechtold@suse.com
  update to version 1.6.0
  * Fix coverage target
  * Add test for 'port-show --field' command
  * Negative tests for testing chassis-create command
  * Add provision state commands
  * Fix typo in docstring of assertTableHeaders method
  * Fix pep8 stderr warning regarding __all__ defined as list
  * Use name randomizer from tempest
  * Trivial: ignore openstack/common in flake8 exclude list
  * Fix quotation mark in docstring
  * Add support for node.resource_class
  * Fix Quick-start example syntax.
  * Add test for chassis-node-list
  * Fix for tox 'testenv:cover' command
  * Add env var for version cache timeout
  * Add invalid attribute names to exception
  * Code style fix according to flake8
  * Improve output of --json option
  * Update reno for stable/mitaka
  * Change position in assert arguments
  * Trivial: Fix incorrect comments in test_baremetal.py
  * Add Python 3.5 classifier and venv
  * Add sanity tests for testing actions with Port
  * Bring OSC plugin inline with approved spec
  * Replace deprecated tempest-lib with tempest
  * Grammatical fixes for cache expiry feature
  * Remove httplib2
  * Fix typos in docstrings and comments
  * Catch RetriableConnectionFailures from KAuth and retry
  * Add baremetal port show command to OSC plugin
  * Add test for 'chassis-show --field' command
  * Implementation of baremetal power state commands
  * Add test for ironic node-list command
  * Updates supporting ironic-neutron integration
  * Tests for CLI help message
  * Add test for ironic driver-list command
  * Fix py35 unit tests
  * Simplify use of config_drive arg in osc
  * Fix error returned by ironic --json node-validate
  * Negative tests for testing actions with Chassis
  * Move methods to utils.py
  * Set endpoint_override while doing session.request
  * Update the home-page with developer documentation
  * Add maintenance mode commands
  * Client addition for Active Node Creation verb adopt
  * Trivial: Fix wrong comment in power state test
  * Implementation of baremetal port create
  * Add CLI tests to check JSON response body
  * Updated from global requirements
  * Add release note link for client release notes
  * Add test for 'node-show --field' command
- update _service and switch to upstream spec template
* Mon Mar 14 2016 tbechtold@suse.com
- update to 1.2.0:
  * Remove leftover use of args.os_endpoint
  * Updated from global requirements
  * Add CLI support for RAID configuration
  * Use keystoneauth instead of keystoneclient
  * Don't ignore failures when delete nodes
  * Use requests lib in HTTPClient
  * Add a JSON option to the client
  * Do not pass endpoint to constructor in OSC
  * Fix Resource.__eq__ mismatch semantics of object equal
  * Log SHA1 hash of X-Auth-Token value
  * Stop ignoring _ as builtin in pep8
  * Remove unused `anyjson`
  * Add sanity tests for testing actions with Chassis
  * Add 'node-set-provision-state <node> clean'
  * continue to delete next node if failed with previous one
  * Fix unit test 'Argument parse failed' error
  * Replace HTTP 'magic numbers' with constants
  * Add CLI to list nodes using the same driver
  * Allow functional tests to work with Keystone v3
  * Allow to initialize keystone v3 client
  * Support all API versions up to 1.latest
  * Put py34 first in the env order of tox
  * Fix params order in assertEqual
  * Remove openstack-common.conf
  * Move ironicclient/common tests to their respective directory
  * Do not log secrets
  * Fix test cases of listing with provisioning state
  * Replace assertTrue with explicit assertIsInstance
  * Add first reno-based release note
  * Add reno for release notes management
  * Add Sanity tests for testing actions with Driver
  * Replace assertEqual(None, *) with assertIsNone in tests
  * Removes MANIFEST.in as it is not needed explicitely by PBR
  * Switch tox unit test command to use ostestr
  * Drop py33 support
  * Add --uuid to port-create
  * Add --uuid to chassis-create
  * Deprecated tox -downloadcache option removed
  * Scale back on how many warnings we issue
  * Refactoring and removing duplicate code of "base.Manager" heirs without changing the API
  * Correct node-port-list help info
  * Fix exceptions.from_response() parameter
  * Tests for testing node-set-power-state command
  * Add --wrap option for "ironic driver-properties"
  * Fix misprints in docstring
  * Revert "Refactoring and removing duplicate code of "base.Manager" heirs"
  * Refactoring and removing duplicate code of "base.Manager" heirs
  * Add sanity tests for testing actions with Node
  * Remove httpretty workaround
  * Use a dict to translate node power states to json data
  * Use requests-mock instead of httpretty
  * Add missing translation markers
  * update node shell help info
  * replace LOG.warn with LOG.warning
  * A minor change for driver_shell test
  * Add documentation on how to run tests
  * Add driver-get-vendor-passthru-methods cmd
  * Add a new cmd method node-get-vendor-passthru-methods
  * Add more unit tests for clituils
  * Drop explicit Python 2.6 support
  * Make print_list accept a list of dict
  * Sync with oslo-incubator
  * Last sync from oslo-incubator
  * Use keystoneclient.exception directly
  * Add simple table structure Ironic CLI tests
  * Introduce tempest-lib to functional tests
  * Make sort keys the same for list commands
  * Remove lxml requirement
  * Mock keystone call to avoid test failure
  * Add more filters for chassis node-list
  * Use doc8 style checker
  * Fix the bug of incorrect spelling
  * Replace six.iteritems() with .items()
  * Allow 'abort' verb for node-set-provision-state
  * Set a default endpoint value of None
  * Added unit test cases for command-line shell
  * Introduce openstackclient plugin
  * Remove unneeded param['detail'] setting
- Adjust Requires and BuildRequires
* Sat Sep 19 2015 tbechtold@suse.com
- update to 0.8.1:
  * Fixes file cache TypeError
  * Fix functional tests job
  * Replace ConfigParser with six.moves.configparser
* Mon Sep 14 2015 tbechtold@suse.com
- update to 0.8.0:
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Added unit tests for command-line shell
  * Also retry on connection refused
  * Updated from global requirements
  * Updated from global requirements
  * Add provision_updated_at field to nodes
  * Filtering nodes by provision state
  * Replacing dict.iteritems() with dict.items()
  * Updated from global requirements
  * Fix version negotiation
  * Updated from global requirements
  * Allow specifying a set of fields of the Port and Chasis resources
  * Revert: requirement files in alphabetical order
  * Fix unittests due mock 1.1.0 release
  * Allow specifying a set of fields of the Node resource
  * Expose node's clean_step and bump default version
  * Fix slow tests in RetriesTestCase
  * Updated from global requirements
  * Updated from global requirements
  * Also retry on HTTP 503 (service unavailable)
  * Cache negotiated api microversion for server
  * Updated from global requirements
  * Cleanup session creation
  * Updated from global requirements
  * Register global Keystone args first
  * Install the ironicclient into the 'venv' virtualenv
  * Updated from global requirements
  * Refactor resource_fields.py
- Adjust Requires according to requirements.txt
* Thu May 28 2015 cloud-devel@suse.de
- Update to version python-ironicclient-0.6.1.dev21:
  * Disable meaningless sort keys in list command
* Wed May 27 2015 cloud-devel@suse.de
- Update to version python-ironicclient-0.6.1.dev19:
  * Add node-show-states command
* Tue May 26 2015 cloud-devel@suse.de
- Update to version python-ironicclient-0.6.1.dev17:
  * httpretty can fail in Python 3.4 with wrong LC_ALL
  * Revert fix that issues Unauthorized exception
  * Consistent and more valid strings for Booleans
* Fri May 15 2015 cloud-devel@suse.de
- Update to version python-ironicclient-0.6.1.dev12:
  * Updated from global requirements
* Fri May  8 2015 cloud-devel@suse.de
- Update to version python-ironicclient-0.6.1.dev11:
  * Sync oslo.incubator
* Thu May  7 2015 cloud-devel@suse.de
- Update to version python-ironicclient-0.6.1.dev10:
  * Drop use of 'oslo' namespace package
  * Disable invalid sort key in list command
* Fri May  1 2015 cloud-devel@suse.de
- Update to version python-ironicclient-0.6.0.post9:
  * Updated from global requirements
  * Add in support for a tox pypy target
* Mon Apr 27 2015 cloud-devel@suse.de
- Update to version python-ironicclient-0.6.0.post6:
  * Ensure *-show input uuid is not empty
  * Remove unneeded 'utf-8' coding lines
* Wed Apr 22 2015 tbechtold@suse.com
- Switch to master
* Wed Mar 18 2015 rsalevsky@suse.com
- update to 0.4.1:
  * Rename --configdrive to --config-drive
  * Fix argument for configdrive usage
  * Fix help string for port-list
  * port-list support get-port-from-mac
  * Update requirements.txt
  * cli support --os-endpoint
  * ironicclient node-set-maintenance to accept true/false
  * Updated from global requirements
  * Check if --config-drive is only used with provision state "active"
  * Add --config-drive to node-set-provision-state
  * Add driver_internal_info to node-show output
  * ironicclient handle faultstring when using SessionClient
  * Support setting non-string fields
  * Workflow documentation is now in infra-manual
  * Removed http proxy environment variable so that httpretty can work
  * Fix to properly issue an Unauthorized exception
  * Add option to specify node uuid in node-create subcommand
  * Add IRONIC_URL to README
  * Fix log_curl_request API version duplication
  * Update README
  * Fix node-set-provision-state cmd's help strings
  * Updated from global requirements
  * Add maintenance_reason to node-show output
  * Add 'API' to description of ironic command
  * Fix the usage comment of node-set-power-state cmd
  * Updated from global requirements
  * Fix sphinx warnings
  * VendorPassthru commands to support different HTTP methods
  * Sane parameters for node and driver vendor_passthru()
  * Updated from global requirements
  * Sync apiclient from Oslo
  * Add node-set-maintenance command
  * Fix python-ironicclient crash
  * Adds tty password entry for ironicclient
* Fri Sep 19 2014 dmueller@suse.com
- update to 0.3.0:
  * Replace calls to Mock.assert_not_called
  * Updates to CLI doc
  * Add 'rebuild' option to node-set-provision-state
  * Update README with a bit more info
  * ironic client to use os_region_name if provided
  * Add unit test for "ironic port-update" shell cmd
  * Add unit tests for "ironic node-delete" shell cmd
  * handles keyboard interrupt
  * fixes help string for driver-list
  * Add 'bash-completion' to 'ironic help' response
  * List resources with detail
  * Add sort_key and sort_dir parameters to *-list
  * Fix column headings regression due to switch to cliutils
  * Work toward Python 3.4 support and testing
  * Updated from global requirements
  * Fix misspelled class name AmbigiousAuthSystem
  * Optimize get_by_instance_uuid
  * Show port by MAC address
* Tue Aug 26 2014 dmueller@suse.com
- update to 0.2.1:
  * Adds documentation for ironicclient API
  * Remove py3kcompat module
  * Add documentation for ironic CLI
  * Updated from global requirements
  * Documentation for contributors
  * Fix docstring for client.get_client()
  * Updated from global requirements
  * node-list to show the maintenance field
  * Add main developer page
  * Sync cliutils from oslo
  * Avoid traceback with insufficient auth credentials
  * Add support for 'driver-show' command
  * Updated from global requirements
  * Add set-console-mode, get-console commands
  * Sort requirement files in alphabetical order
  * Filtering nodes by maintenance mode
  * Remove shebang lines from code
  * Fix the test parameter order
  * Return 'maintenance' from node-show command
  * Fix params order in assertEqual
  * Remove vim header
  * Node power state is not printed after set
  * Return node_uuid from a port-show cmd
  * Fix Iterface misspelling from node-validate cmd
  * Remove tox locale overrides
  * Add node.states() to the client library
  * Fix node-create help requiring chassis uuid
  * Updated from global requirements
  * Remove unused method 'string_to_bool' from utils
  * Reuse Resource from oslo
  * Sync apiclient and strutils from Oslo
  * Run unittest with python 3.3
  * Drop python2.5 suport in ironicclient.common.http
  * Improve node-validate command output
  * Add set_provision_state to the client libs
  * ironic client should display chassis_uuid value
  * Update openstack-common.conf list, sync with oslo (0d8f18b)
  * Rename nodes/<uuid>/state to nodes/<uuid>/states
  * Remove unused oslo-incubator modules
  * Updated from global requirements
  * driver-list command to show the list of conductors
* Fri Feb 14 2014 speilicke@suse.com
- Run testr directly
* Tue Feb 11 2014 speilicke@suse.com
- Replace git_tarballs source service with download_files and set_version
  + Use upstream URL as source (enables verification)
* Mon Dec  9 2013 speilicke@suse.com
- Update to version 0.0.1:
  + Replace node_id to node_uuid on PortsLet CLI print exception traceback from 'debuginfo'
  + Move six dependency to requirements.txt
  + Move from inheritance HTTPClient in Ironic client
  + Enable rebooting in the client lib and cli
  + Updated from global requirementsShows 'last_error' property for a node
  + Support building wheels (PEP-427)
  + Include 'chassis_id' on node-show
  + Enable created_at/updated_at for port-show/chassis-show
  + Add missing i18n support
- Add _service file
- Fix dependencies
* Mon Nov 25 2013 dmueller@suse.com
- switch to python-setuptools
* Wed Sep 18 2013 dmueller@suse.com
- Initial package
